==> cscec5b-test-impl-3.0.1-20230222.081904-4-sources.jar: com/ejianc/business/test/vo/GoodsVO.java <==
package com.ejianc.business.test.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 测试资产表
 * 
 * @author generator
 * 
 */
public class GoodsVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 资产编号
    private Long seller; // 发布人
    private String sellerName; // 发布人名称
    private String mainimgPath; // 资产主图URL
    private Long projectId; // 项目主键
    private Long orgId; // 组织主键
    private String projectName; // 项目名称
    private String orgName; // 组织名称
    private String spec; // 规格型号
    private String shelfType; // 资产类型
    private BigDecimal originalprice; // 原价
    private BigDecimal discount; // 折扣
    private BigDecimal price; // 单价
    private BigDecimal nums; // 数量
    private String address; // 详细地址
    private String phone; // 联系方式
    private String name; // 联系人
    private Integer status; // 资产状态0-在售，1-下架，2-暂存
    private BigDecimal shelfMny; // 上架总金额
    private Integer billState; // 单据状态（审批必须字段）
    private String materialCode; // 物资名称
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getSeller() {
        return seller;
    }

    public void setSeller(Long seller) {
        this.seller = seller;
    }
    public String getSellerName() {
        return sellerName;
    }

    public void setSellerName(String sellerName) {
        this.sellerName = sellerName;
    }
    public String getMainimgPath() {
        return mainimgPath;
    }

    public void setMainimgPath(String mainimgPath) {
        this.mainimgPath = mainimgPath;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public String getShelfType() {
        return shelfType;
    }

    public void setShelfType(String shelfType) {
        this.shelfType = shelfType;
    }
    public BigDecimal getOriginalprice() {
        return originalprice;
    }

    public void setOriginalprice(BigDecimal originalprice) {
        this.originalprice = originalprice;
    }
    public BigDecimal getDiscount() {
        return discount;
    }

    public void setDiscount(BigDecimal discount) {
        this.discount = discount;
    }
    public BigDecimal getPrice() {
        return price;
    }

    public void setPrice(BigDecimal price) {
        this.price = price;
    }
    public BigDecimal getNums() {
        return nums;
    }

    public void setNums(BigDecimal nums) {
        this.nums = nums;
    }
    public String getAddress() {
        return address;
    }

    public void setAddress(String address) {
        this.address = address;
    }
    public String getPhone() {
        return phone;
    }

    public void setPhone(String phone) {
        this.phone = phone;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }
    public BigDecimal getShelfMny() {
        return shelfMny;
    }

    public void setShelfMny(BigDecimal shelfMny) {
        this.shelfMny = shelfMny;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    
}

==> cscec5b-test-impl-3.0.1-20230228.090854-11-sources.jar: com/ejianc/business/test/vo/GoodsVO.java <==
package com.ejianc.business.test.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 测试资产表
 * 
 * @author generator
 * 
 */
public class GoodsVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 资产编号
    private Long seller; // 发布人
    private String sellerName; // 发布人名称
    private String mainimgPath; // 资产主图URL
    private Long projectId; // 项目主键
    private Long orgId; // 组织主键
    private String projectName; // 项目名称
    private String orgName; // 组织名称
    private String spec; // 规格型号
    private String shelfType; // 资产类型
    private BigDecimal originalprice; // 原价
    private BigDecimal discount; // 折扣
    private BigDecimal price; // 单价
    private BigDecimal nums; // 数量
    private Integer address; // 详细地址
    private String phone; // 联系方式
    private String name; // 联系人
    private Integer status; // 资产状态0-在售，1-下架，2-暂存
    private BigDecimal shelfMny; // 上架总金额
    private Integer billState; // 单据状态（审批必须字段）
    private String materialCode; // 物资名称
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getSeller() {
        return seller;
    }

    public void setSeller(Long seller) {
        this.seller = seller;
    }
    public String getSellerName() {
        return sellerName;
    }

    public void setSellerName(String sellerName) {
        this.sellerName = sellerName;
    }
    public String getMainimgPath() {
        return mainimgPath;
    }

    public void setMainimgPath(String mainimgPath) {
        this.mainimgPath = mainimgPath;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public String getShelfType() {
        return shelfType;
    }

    public void setShelfType(String shelfType) {
        this.shelfType = shelfType;
    }
    public BigDecimal getOriginalprice() {
        return originalprice;
    }

    public void setOriginalprice(BigDecimal originalprice) {
        this.originalprice = originalprice;
    }
    public BigDecimal getDiscount() {
        return discount;
    }

    public void setDiscount(BigDecimal discount) {
        this.discount = discount;
    }
    public BigDecimal getPrice() {
        return price;
    }

    public void setPrice(BigDecimal price) {
        this.price = price;
    }
    public BigDecimal getNums() {
        return nums;
    }

    public void setNums(BigDecimal nums) {
        this.nums = nums;
    }
    @ReferSerialTransfer(referCode="refGoodsData")
    public Integer getAddress() {
        return address;
    }

    @ReferDeserialTransfer
    public void setAddress(Integer address) {
        this.address = address;
    }
    public String getPhone() {
        return phone;
    }

    public void setPhone(String phone) {
        this.phone = phone;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    @ReferDeserialTransfer
    public Integer getStatus() {
        return status;
    }

    @ReferDeserialTransfer
    public void setStatus(Integer status) {
        this.status = status;
    }
    public BigDecimal getShelfMny() {
        return shelfMny;
    }

    public void setShelfMny(BigDecimal shelfMny) {
        this.shelfMny = shelfMny;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    
}
